@@ -26,7 +26,8 @@ import typing as t
 
 import docspec
 
-from pydoc_markdown.interfaces import Processor, Resolver
+from pydoc_markdown.interfaces import Processor, Resolver, ResolverV2
+from pydoc_markdown.util.docspec import ApiSuite
 
 logger = logging.getLogger(__name__)
 
@@ -56,17 +57,19 @@ class CrossrefProcessor(Processor):
 
   Example configuration:
 
-  ```yml
+  ```yaml
   processors:
     - type: crossref
   ```
   """
 
+  #: If specified, it will be used instead of the resolver passed to #process() and the generated Markdown
+  #: code for the reference uses Novella `{@link}` syntax.
+  resolver_v2: t.Optional[ResolverV2] = None
+
   def process(self, modules: t.List[docspec.Module], resolver: t.Optional[Resolver]) -> None:
     unresolved: t.Dict[str, t.List[str]] = {}
-    if resolver:
-      reverse = docspec.ReverseMap(modules)
-      docspec.visit(modules, lambda x: self._preprocess_refs(x, resolver, reverse, unresolved))
+    docspec.visit(modules, lambda x: self._preprocess_refs(x, t.cast(Resolver, resolver), ApiSuite(modules), unresolved))
 
     if unresolved:
       summary = []
@@ -82,14 +85,14 @@ class CrossrefProcessor(Processor):
   def _preprocess_refs(
     self,
     node: docspec.ApiObject,
-    resolver: Resolver,
-    reverse: docspec.ReverseMap,
+    resolver: t.Optional[Resolver],
+    suite: ApiSuite,
     unresolved: t.Dict[str, t.List[str]],
   ) -> None:
     if not node.docstring:
       return
 
-    def handler(match):
+    def handler(match: re.Match) -> str:
       ref = match.group('ref')
       parens = match.group('parens') or ''
       trailing = (match.group('trailing') or '').lstrip('#')
@@ -102,19 +105,34 @@ class CrossrefProcessor(Processor):
       elif not parens and ref.endswith('.'):
         ref = ref[:-1]
         has_trailing_dot = True
-      href = resolver.resolve_ref(node, ref)
-      if href:
-        result = '[`{}`]({})'.format(ref + parens + trailing, href)
-      else:
-        uid = '.'.join(x.name for x in reverse.path(node))
+
+      text = ref + parens + trailing
+      result: t.Optional[str] = None
+
+      if self.resolver_v2:
+        target = self.resolver_v2.resolve_reference(suite, node, ref)
+        if target:
+          import tomli_w
+          opt = tomli_w.dumps({"text": text})
+          result = f'{{@link pydoc:{".".join(x.name for x in target.path)} :with {opt}}}'
+
+      elif resolver:
+        href = resolver.resolve_ref(node, ref)
+        if href:
+          result = '[`{}`]({})'.format(text, href)
+
+      if result is None:
+        uid = '.'.join(x.name for x in node.path)
         unresolved.setdefault(uid, []).append(ref)
-        result = '`{}`'.format(ref + parens)
+        result = '`{}`'.format(ref + parens + trailing)
+
       # Add back the dot.
       if has_trailing_dot:
         result += '.'
+
       return result
 
-    node.docstring = re.sub(
+    node.docstring.content = re.sub(
       r'\B#(?P<ref>[\w\d\._]+)(?P<parens>\(\))?(?P<trailing>#[\w\d\._]+)?',
       handler,
-      node.docstring)
+      node.docstring.content)
