@@ -250,11 +250,11 @@ class MarkdownRenderer(Renderer, SinglePageRenderer, SingleObjectRenderer):
       # in the field will act as a first fallback, the level of the object inside it's
       # hierarchy is the final fallback.
       header_levels = {
-        **self.header_level_by_type,
         **type(self).__dataclass_fields__['header_level_by_type'].default_factory(),
+        **self.header_level_by_type,
       }
-      # Backwards compat for whe we used "Data" instead of "Variable" which mirrors the docspec API
-      header_levels['Data'] = header_levels.get('Variable', level)
+      # Backwards compat for when we used "Data" instead of "Variable" which mirrors the docspec API
+      header_levels['Variable'] = header_levels.get('Data', header_levels['Variable'])
 
       type_name = 'Method' if self._is_method(obj) else type(obj).__name__
       level = header_levels.get(type_name, level)
